@@ -24,6 +24,7 @@ import ssl
 import sys
 import threading
 import time
+from urllib import parse
 import uuid
 
 from amqp import exceptions as amqp_exec
@@ -35,9 +36,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import eventletutils
 from oslo_utils import importutils
-import six
-import six.moves
-from six.moves.urllib import parse
 
 import oslo_messaging
 from oslo_messaging._drivers import amqp as rpc_amqp
@@ -169,18 +167,12 @@ rabbit_opts = [
                default=2,
                help='How often times during the heartbeat_timeout_threshold '
                'we check the heartbeat.'),
-    cfg.BoolOpt('direct_mandatory_flag',
-                default=True,
-                deprecated_for_removal=True,
-                deprecated_reason='Mandatory flag no longer deactivable.',
-                help='(DEPRECATED) Enable/Disable the RabbitMQ mandatory '
-                'flag for direct send. The direct send is used as reply, '
-                'so the MessageUndeliverable exception is raised '
-                'in case the client queue does not exist.'
-                'MessageUndeliverable exception will be used to loop for a '
-                'timeout to lets a chance to sender to recover.'
-                'This flag is deprecated and it will not be possible to '
-                'deactivate this functionality anymore'),
+    cfg.IntOpt('direct_mandatory_flag',
+               default=True,
+               help='Enable/Disable the RabbitMQ mandatory flag '
+               'for direct send. The direct send is used as reply, '
+               'so the MessageUndeliverable exception is raised '
+               'in case the client queue does not exist.'),
     cfg.BoolOpt('enable_cancel_on_failover',
                 default=False,
                 help="Enable x-cancel-on-ha-failover flag so that "
@@ -341,7 +333,7 @@ class Consumer(object):
             self.declare(conn)
         try:
             self.queue.consume(callback=self._callback,
-                               consumer_tag=six.text_type(tag),
+                               consumer_tag=str(tag),
                                nowait=self.nowait)
         except conn.connection.channel_errors as exc:
             # We retries once because of some races that we can
@@ -361,14 +353,14 @@ class Consumer(object):
                                    exc.method_name == 'Basic.ack'):
                 self.declare(conn)
                 self.queue.consume(callback=self._callback,
-                                   consumer_tag=six.text_type(tag),
+                                   consumer_tag=str(tag),
                                    nowait=self.nowait)
             else:
                 raise
 
     def cancel(self, tag):
         LOG.trace('ConsumerBase.cancel: canceling %s', tag)
-        self.queue.cancel(six.text_type(tag))
+        self.queue.cancel(str(tag))
 
     def _callback(self, message):
         """Call callback with deserialized message.
@@ -518,7 +510,6 @@ class Connection(object):
             # if it was already monkey patched by eventlet/greenlet.
             global threading
             threading = stdlib_threading
-
         self.direct_mandatory_flag = driver_conf.direct_mandatory_flag
 
         if self.ssl:
@@ -549,7 +540,10 @@ class Connection(object):
                 self._url += url.virtual_host
         elif not url.hosts:
             host = oslo_messaging.transport.TransportHost('')
-            self._url = self._transform_transport_url(
+            # NOTE(moguimar): default_password in this function's context is
+            #                 a fallback option, not a hardcoded password.
+            #                 username and password are read from host.
+            self._url = self._transform_transport_url(  # nosec
                 url, host, default_username='guest', default_password='guest',
                 default_hostname='localhost')
 
@@ -679,7 +673,9 @@ class Connection(object):
         except KeyError:
             raise RuntimeError("Invalid SSL version : %s" % version)
 
-    def _transform_transport_url(self, url, host, default_username='',
+    # NOTE(moguimar): default_password in this function's context is just
+    #                 a fallback option, not a hardcoded password.
+    def _transform_transport_url(self, url, host, default_username='',  # nosec
                                  default_password='', default_hostname=''):
         transport = url.transport.replace('kombu+', '')
         transport = transport.replace('rabbit', 'amqp')
@@ -776,7 +772,7 @@ class Connection(object):
             info = {'err_str': exc, 'sleep_time': interval}
             info.update(self._get_connection_info(conn_error=True))
 
-            if 'Socket closed' in six.text_type(exc):
+            if 'Socket closed' in str(exc):
                 LOG.error('[%(connection_id)s] AMQP server'
                           ' %(hostname)s:%(port)s closed'
                           ' the connection. Check login credentials:'
@@ -890,8 +886,8 @@ class Connection(object):
         """Close/release this connection."""
         self._heartbeat_stop()
         if self.connection:
-            for consumer in six.moves.filter(lambda c: c.type == 'fanout',
-                                             self._consumers):
+            for consumer in filter(lambda c: c.type == 'fanout',
+                                   self._consumers):
                 LOG.debug('[connection close] Deleting fanout '
                           'queue: %s ' % consumer.queue.name)
                 consumer.queue.delete()
@@ -1000,13 +996,6 @@ class Connection(object):
     def _heartbeat_thread_job(self):
         """Thread that maintains inactive connections
         """
-        # NOTE(hberaud): Python2 doesn't have ConnectionRefusedError
-        # defined so to switch connections destination on failure
-        # with python2 and python3 we need to wrapp adapt connection refused
-        try:
-            ConnectRefuseError = ConnectionRefusedError
-        except NameError:
-            ConnectRefuseError = socket.error
 
         while not self._heartbeat_exit_event.is_set():
             with self._connection_lock.for_heartbeat():
@@ -1033,7 +1022,7 @@ class Connection(object):
                     # ensure_connection for switching the
                     # connection destination.
                     except (socket.timeout,
-                            ConnectRefuseError,
+                            ConnectionRefusedError,
                             OSError,
                             kombu.exceptions.OperationalError,
                             amqp_exec.ConnectionForced) as exc:
@@ -1398,10 +1387,6 @@ class RabbitDriver(amqpdriver.AMQPDriverBase):
         # the pool configuration properties
         max_size = conf.oslo_messaging_rabbit.rpc_conn_pool_size
         min_size = conf.oslo_messaging_rabbit.conn_pool_min_size
-        if max_size < min_size:
-            raise RuntimeError(
-                f"rpc_conn_pool_size: {max_size} must be greater than "
-                f"or equal to conn_pool_min_size: {min_size}")
         ttl = conf.oslo_messaging_rabbit.conn_pool_ttl
 
         connection_pool = pool.ConnectionPool(
